# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['frenchbee']

package_data = \
{'': ['*']}

install_requires = \
['beautifulsoup4>=4.11.1,<5.0.0',
 'jsonpath-ng>=1.5.3,<2.0.0',
 'requests>=2.27.1,<3.0.0']

entry_points = \
{'console_scripts': ['frenchbee-cli = frenchbee.cli:main']}

setup_kwargs = {
    'name': 'frenchbee',
    'version': '0.1.1',
    'description': 'Python client for finding French Bee airline prices.',
    'long_description': '# French Bee\nPython client for finding French Bee airline prices.\n\n# Installation\n```\npip install frenchbee\n```\n\n# Usage\nThe [FrenchBeeData](frenchbee/data.py) class is used for looking up travel location codes that French Bee airlines supports. Note that locations include airports and train stations. Available methods are:\n- [get_locations()](#get-locations): Get all the supported airport and train stations.\n\nThe [FrenchBee](frenchbee/frenchbee.py) class is used for looking up flight prices and times. Available methods are:\n- [get_departure_info_for(...)](#get-departure-info): Get pricing info for a specific departure day between two locations.\n- [get_departure_availability(...)](#get-departure-availability): Get pricing info between two locations for the next few months.\n- [get_return_info_for(...)](#get-return-info): Get pricing info for a specific departure and return day between two locations.\n- [get_return_availability(...)](#get-return-availability): Get return pricing info for a specific departure day between two locations for the next few months.\n- [get_flight_times(...)](#get-flight-times): Get flight times info for a specific departure and return day between two locations.\n\n## Get Locations\nGet all the French Bee supported airport and train stations.\n\n### Example\n```\nfrom frenchbee import FrenchBeeData, Location\n\nclient: FrenchBeeData = FrenchBeeData()\nlocations: List[Location] = list(client.get_locations())\nfor location in locations:\n  print(location.json())\n```\n\n### Results\n```\n{\'code\': \'PUJ\', \'name\': \'Punta Cana, Dominican Republic\'}\n{\'code\': \'QXB\', \'name\': \'Aix-en-provence TGV (Railway Station), France \'}\n{\'code\': \'QXG\', \'name\': \'Angers St-Laud TGV (Railway Station), France \'}\n```\n\n## Get Departure Info\nGet pricing info for a specific departure day between two locations.\n\n### Example\n```\nfrom datetime import datetime\nfrom frenchbee import FrenchBee\nfrom frenchbee import Trip, PassengerInfo, DateAndLocation, Location, Flight\n\ntrip: Trip = Trip(\n  origin_depart=DateAndLocation(\n    date=datetime(2022, 10, 6), location=Location("EWR")\n  ),\n  destination_return=DateAndLocation(\n    date=None, location=Location("ORY")\n  ),\n  passengers=PassengerInfo(Adults=1),\n)\n\nclient: FrenchBee = FrenchBee()\nflight: Flight = client.get_departure_info_for(trip)\nprint(flight.json())\n```\n\n### Results\n```\n{\'arrival_airport\': \'ORY\', \'currency\': \'USD\', \'day\': \'2022-10-06\', \'departure_airport\': \'EWR\', \'is_offer\': False, \'price\': 264.0, \'tax\': 117.3}\n```\n\n## Get Departure Availability\nGet pricing info between two locations for the next few months.\n\n### Example\n```\nfrom datetime import datetime\nfrom frenchbee import FrenchBee\nfrom frenchbee import Trip, PassengerInfo, DateAndLocation, Location, Flight\n\ntrip: Trip = Trip(\n  origin_depart=DateAndLocation(\n    date=None, location=Location("EWR")\n  ),\n  destination_return=DateAndLocation(\n    date=None, location=Location("ORY")\n  ),\n  passengers=PassengerInfo(Adults=1),\n)\n\nclient: FrenchBee = FrenchBee()\nflights: Dict[datetime, Flight] = client.get_departure_availability(trip)\nfor date, flight in flights.items():\n  print(date, flight.json())\n```\n\n### Results\n```\n2022-05-28 00:00:00 {\'arrival_airport\': \'ORY\', \'currency\': \'USD\', \'day\': \'2022-05-28\', \'departure_airport\': \'EWR\', \'is_offer\': False, \'price\': 1115.0, \'tax\': 117.3}\n2022-05-29 00:00:00 {\'arrival_airport\': \'ORY\', \'currency\': \'USD\', \'day\': \'2022-05-29\', \'departure_airport\': \'EWR\', \'is_offer\': True, \'price\': 1015.0, \'tax\': 117.3}\n2022-05-30 00:00:00 {\'arrival_airport\': \'ORY\', \'currency\': \'USD\', \'day\': \'2022-05-30\', \'departure_airport\': \'EWR\', \'is_offer\': True, \'price\': 1015.0, \'tax\': 117.3}\n```\n\n\n\n\n## Get Return Info\nGet pricing info for a specific departure and return day between two locations.\n\n### Example\n```\nfrom datetime import datetime\nfrom frenchbee import FrenchBee\nfrom frenchbee import Trip, PassengerInfo, DateAndLocation, Location, Flight\n\ntrip: Trip = Trip(\n  origin_depart=DateAndLocation(\n    date=datetime(2022, 10, 6), location=Location("EWR")\n  ),\n  destination_return=DateAndLocation(\n    date=datetime(2022, 10, 10), location=Location("ORY")\n  ),\n  passengers=PassengerInfo(Adults=1),\n)\n\nclient: FrenchBee = FrenchBee()\nflight: Flight = client.get_return_info_for(trip)\nprint(flight.json())\n```\n\n### Results\n```\n{\'arrival_airport\': \'EWR\', \'currency\': \'USD\', \'day\': \'2022-10-10\', \'departure_airport\': \'ORY\', \'is_offer\': False, \'price\': 332.0, \'tax\': 186.47}\n```\n\n## Get Return Availability\nGet return pricing info for a specific departure day between two locations for the next few months.\n\n### Example\n```\nfrom datetime import datetime\nfrom frenchbee import FrenchBee\nfrom frenchbee import Trip, PassengerInfo, DateAndLocation, Location, Flight\n\ntrip: Trip = Trip(\n  origin_depart=DateAndLocation(\n    date=datetime(2022, 10, 6), location=Location("EWR")\n  ),\n  destination_return=DateAndLocation(\n    date=None, location=Location("ORY")\n  ),\n  passengers=PassengerInfo(Adults=1),\n)\n\nclient: FrenchBee = FrenchBee()\nflights: Dict[datetime, Flight] = client.get_return_availability(trip)\nfor date, flight in flights.items():\n  print(date, flight.json())\n```\n\n### Results\n```\n2022-10-07 00:00:00 {\'arrival_airport\': \'EWR\', \'currency\': \'USD\', \'day\': \'2022-10-07\', \'departure_airport\': \'ORY\', \'is_offer\': False, \'price\': 332.0, \'tax\': 186.47}\n2022-10-08 00:00:00 {\'arrival_airport\': \'EWR\', \'currency\': \'USD\', \'day\': \'2022-10-08\', \'departure_airport\': \'ORY\', \'is_offer\': False, \'price\': 332.0, \'tax\': 186.47}\n2022-10-09 00:00:00 {\'arrival_airport\': \'EWR\', \'currency\': \'USD\', \'day\': \'2022-10-09\', \'departure_airport\': \'ORY\', \'is_offer\': False, \'price\': 332.0, \'tax\': 186.47}\n```\n\n\n\n\n## Get Flight Times\nGet flight times info for a specific departure and return day between two locations.\n\n### Example\n```\nfrom datetime import datetime\nfrom frenchbee import FrenchBee\nfrom frenchbee import Trip, PassengerInfo, DateAndLocation, Location, Flight\n\ntrip: Trip = Trip(\n  origin_depart=DateAndLocation(\n    date=datetime(2022, 10, 6), location=Location("EWR")\n  ),\n  destination_return=DateAndLocation(\n    date=datetime(2022, 10, 10), location=Location("ORY")\n  ),\n  passengers=PassengerInfo(Adults=1),\n)\n\nclient: FrenchBee = FrenchBee()\ntrip: Trip = client.get_flight_times(trip)\nprint(trip.json())\n```\n\n### Results\n```\n{\'destination_return\': {\'date\': \'2022-10-10\', \'location\': {\'code\': \'ORY\'}},\n \'destination_segments\': [[{\'airline_code\': \'BF\',\n                            \'airline_name\': \'French Bee\',\n                            \'duration\': 29700000,\n                            \'end\': {\'date\': \'2022-10-11 01:00:00\',\n                                    \'location\': {\'code\': \'EWR\',\n                                                 \'name\': \'Newark Liberty \'\n                                                         \'International\',\n                                                 \'terminal\': \'B\'}},\n                            \'flight_num\': \'720\',\n                            \'start\': {\'date\': \'2022-10-10 16:45:00\',\n                                      \'location\': {\'code\': \'ORY\',\n                                                   \'name\': \'Orly\',\n                                                   \'terminal\': \'4\',\n                                                   \'transport\': \'Airbus \'\n                                                                \'A350-900\'}}}]],\n \'origin_depart\': {\'date\': \'2022-10-06\', \'location\': {\'code\': \'EWR\'}},\n \'origin_segments\': [[{\'airline_code\': \'BF\',\n                       \'airline_name\': \'French Bee\',\n                       \'duration\': 26700000,\n                       \'end\': {\'date\': \'2022-10-07 10:20:00\',\n                               \'location\': {\'code\': \'ORY\',\n                                            \'name\': \'Orly\',\n                                            \'terminal\': \'4\'}},\n                       \'flight_num\': \'721\',\n                       \'start\': {\'date\': \'2022-10-07 02:55:00\',\n                                 \'location\': {\'code\': \'EWR\',\n                                              \'name\': \'Newark Liberty \'\n                                                      \'International\',\n                                              \'terminal\': \'B\',\n                                              \'transport\': \'Airbus \'\n                                                           \'A350-900\'}}}]],\n \'passengers\': {\'Adults\': 1, \'Children\': 0, \'Infants\': 0}}\n```\n\n\n\n# CLI Usage\nThis package comes bundled with a CLI tool for exploring French Bee prices and times, succinctly named `frenchbee-cli` that can be installed via `poetry install`.\n\n```\nusage: frenchbee-cli [-h] {data,flight} ...\n\nGet French Bee airline prices.\n\npositional arguments:\n  {data,flight}\n    data         Get metadata about French Bee locations.\n    flight       Get flight information.\n\noptions:\n  -h, --help     show this help message and exit\n```\n\n## Get Locations\n```\n>>> frenchbee-cli data --help     \nusage: frenchbee-cli data [-h] [--locations]\n\noptions:\n  -h, --help   show this help message and exit\n  --locations  Get all supported locations.\n\n>>> frenchbee-cli data --locations\n\n{\'code\': \'PUJ\', \'name\': \'Punta Cana, Dominican Republic\'}\n{\'code\': \'QXB\', \'name\': \'Aix-en-provence TGV (Railway Station), France \'}\n{\'code\': \'QXG\', \'name\': \'Angers St-Laud TGV (Railway Station), France \'}\n```\n\n## Get Flight Times\n```\n>>> frenchbee-cli flight EWR ORY 2022-10-06 2022-10-10\n\n{\'arrival_airport\': \'ORY\', \'currency\': \'USD\', \'day\': \'2022-10-06\', \'departure_airport\': \'EWR\', \'is_offer\': False, \'price\': 264.0, \'tax\': 117.3}\n{\'arrival_airport\': \'EWR\', \'currency\': \'USD\', \'day\': \'2022-10-10\', \'departure_airport\': \'ORY\', \'is_offer\': False, \'price\': 332.0, \'tax\': 186.47}\nTotal price: $596.0 for 2022-10-06 00:00:00 to 2022-10-10 00:00:00 from EWR to ORY\n{\'destination_return\': {\'date\': \'2022-10-10\', \'location\': {\'code\': \'ORY\'}},\n \'destination_segments\': [[{\'airline_code\': \'BF\',\n                            \'airline_name\': \'French Bee\',\n                            \'duration\': 29700000,\n                            \'end\': {\'date\': \'2022-10-11 01:00:00\',\n                                    \'location\': {\'code\': \'EWR\',\n                                                 \'name\': \'Newark Liberty \'\n                                                         \'International\',\n                                                 \'terminal\': \'B\'}},\n                            \'flight_num\': \'720\',\n                            \'start\': {\'date\': \'2022-10-10 16:45:00\',\n                                      \'location\': {\'code\': \'ORY\',\n                                                   \'name\': \'Orly\',\n                                                   \'terminal\': \'4\',\n                                                   \'transport\': \'Airbus \'\n                                                                \'A350-900\'}}}]],\n \'origin_depart\': {\'date\': \'2022-10-06\', \'location\': {\'code\': \'EWR\'}},\n \'origin_segments\': [[{\'airline_code\': \'BF\',\n                       \'airline_name\': \'French Bee\',\n                       \'duration\': 26700000,\n                       \'end\': {\'date\': \'2022-10-07 10:20:00\',\n                               \'location\': {\'code\': \'ORY\',\n                                            \'name\': \'Orly\',\n                                            \'terminal\': \'4\'}},\n                       \'flight_num\': \'721\',\n                       \'start\': {\'date\': \'2022-10-07 02:55:00\',\n                                 \'location\': {\'code\': \'EWR\',\n                                              \'name\': \'Newark Liberty \'\n                                                      \'International\',\n                                              \'terminal\': \'B\',\n                                              \'transport\': \'Airbus \'\n                                                           \'A350-900\'}}}]],\n \'passengers\': {\'Adults\': 1, \'Children\': 0, \'Infants\': 0}}\n```\n\n# Docker\nContainers are automatically built off of the main branch and can be downloaded from:\nhttps://hub.docker.com/repository/docker/minormending/frenchbee\n\nAlternatively, you can build your own containers:\n```\n>>> docker build -t frenchbee .\n>>> docker run frenchbee flight EWR ORY 2022-10-06 2022-10-10\n\n{\'arrival_airport\': \'ORY\', \'currency\': \'USD\', \'day\': \'2022-10-06\', \'departure_airport\': \'EWR\', \'is_offer\': False, \'price\': 264.0, \'tax\': 117.3}\n{\'arrival_airport\': \'EWR\', \'currency\': \'USD\', \'day\': \'2022-10-10\', \'departure_airport\': \'ORY\', \'is_offer\': False, \'price\': 332.0, \'tax\': 186.47}\nTotal price: $596.0 for 2022-10-06 00:00:00 to 2022-10-10 00:00:00 from EWR to ORY\n{\'destination_return\': {\'date\': \'2022-10-10\', \'location\': {\'code\': \'ORY\'}},\n \'destination_segments\': [[{\'airline_code\': \'BF\',\n                            \'airline_name\': \'French Bee\',\n                            \'duration\': 29700000,\n                            \'end\': {\'date\': \'2022-10-11 01:00:00\',\n                                    \'location\': {\'code\': \'EWR\',\n                                                 \'name\': \'Newark Liberty \'\n                                                         \'International\',\n                                                 \'terminal\': \'B\'}},\n                            \'flight_num\': \'720\',\n                            \'start\': {\'date\': \'2022-10-10 16:45:00\',\n                                      \'location\': {\'code\': \'ORY\',\n                                                   \'name\': \'Orly\',\n                                                   \'terminal\': \'4\',\n                                                   \'transport\': \'Airbus \'\n                                                                \'A350-900\'}}}]],\n \'origin_depart\': {\'date\': \'2022-10-06\', \'location\': {\'code\': \'EWR\'}},\n \'origin_segments\': [[{\'airline_code\': \'BF\',\n                       \'airline_name\': \'French Bee\',\n                       \'duration\': 26700000,\n                       \'end\': {\'date\': \'2022-10-07 10:20:00\',\n                               \'location\': {\'code\': \'ORY\',\n                                            \'name\': \'Orly\',\n                                            \'terminal\': \'4\'}},\n                       \'flight_num\': \'721\',\n                       \'start\': {\'date\': \'2022-10-07 02:55:00\',\n                                 \'location\': {\'code\': \'EWR\',\n                                              \'name\': \'Newark Liberty \'\n                                                      \'International\',\n                                              \'terminal\': \'B\',\n                                              \'transport\': \'Airbus \'\n                                                           \'A350-900\'}}}]],\n \'passengers\': {\'Adults\': 1, \'Children\': 0, \'Infants\': 0}}\n```',
    'author': 'Kevin Ramdath',
    'author_email': 'krpent@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/minormending/frenchbee',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
